JQuery Scrollspy demo

# Here's some text content before the navigation

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nihil opus est exemplis hoc facere longius. In his igitur partibus duabus nihil erat, quod Zeno commutare gestiret. Duo Reges: constructio interrete. Quid nunc honeste dicit? Age, inquies, ista parva sunt. Si id dicis, vicimus.

Primum quid tu dicis breve? Nam ista vestra: Si gravis, brevis; Tollenda est atque extrahenda radicitus. Recte dicis; Est enim effectrix multarum et magnarum voluptatum. Vide ne ista sint Manliana vestra aut maiora etiam, si imperes quod facere non possim. Qua tu etiam inprudens utebare non numquam. Atque haec ita iustitiae propria sunt, ut sint virtutum reliquarum communia.

                  Nam neque virtute retinetur ille in vita, nec iis, qui sine
                  virtute sunt, mors est oppetenda.

                  Quid enim ab antiquis ex eo genere, quod ad disserendum
                  valet, praetermissum est?

Immo videri fortasse. Minime vero istorum quidem, inquit. Pugnant Stoici cum Peripateticis. Sed quot homines, tot sententiae;

Haeret in salebra. Estne, quaeso, inquam, sitienti in bibendo voluptas? Octavio fuit, cum illam severitatem in eo filio adhibuit, quem in adoptionem D. Scrupulum, inquam, abeunti; De malis autem et bonis ab iis animalibus, quae nondum depravata sint, ait optime iudicari. Cum id fugiunt, re eadem defendunt, quae Peripatetici, verba.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nihil opus est exemplis hoc facere longius. In his igitur partibus duabus nihil erat, quod Zeno commutare gestiret. Duo Reges: constructio interrete. Quid nunc honeste dicit? Age, inquies, ista parva sunt. Si id dicis, vicimus.

Primum quid tu dicis breve? Nam ista vestra: Si gravis, brevis; Tollenda est atque extrahenda radicitus. Recte dicis; Est enim effectrix multarum et magnarum voluptatum. Vide ne ista sint Manliana vestra aut maiora etiam, si imperes quod facere non possim. Qua tu etiam inprudens utebare non numquam. Atque haec ita iustitiae propria sunt, ut sint virtutum reliquarum communia.

                  Nam neque virtute retinetur ille in vita, nec iis, qui sine
                  virtute sunt, mors est oppetenda.

                  Quid enim ab antiquis ex eo genere, quod ad disserendum
                  valet, praetermissum est?

Immo videri fortasse. Minime vero istorum quidem, inquit. Pugnant Stoici cum Peripateticis. Sed quot homines, tot sententiae;

Haeret in salebra. Estne, quaeso, inquam, sitienti in bibendo voluptas? Octavio fuit, cum illam severitatem in eo filio adhibuit, quem in adoptionem D. Scrupulum, inquam, abeunti; De malis autem et bonis ab iis animalibus, quae nondum depravata sint, ait optime iudicari. Cum id fugiunt, re eadem defendunt, quae Peripatetici, verba.

# Tu enim ista lenius, hic Stoicorum more nos vexat.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Dicet pro me ipsa virtus nec dubitabit isti vestro beato M. Sed residamus, inquit, si placet. Si quae forte-possumus. Quid censes in Latino fore? Duo Reges: constructio interrete. Nummus in Croesi divitiis obscuratur, pars est tamen divitiarum. An tu me de L. Quae contraria sunt his, malane? An potest, inquit ille, quicquam esse suavius quam nihil dolere? Itaque in rebus minime obscuris non multus est apud eos disserendi labor.

> Omne enim animal, simul et ortum est, se ipsum et omnes partes suas diligit duasque, quae maximae sunt, in primis amplectitur, animum et corpus, deinde utriusque partes.

Bonum incolumis acies: misera caecitas. Ego vero volo in virtute vim esse quam maximam; Traditur, inquit, ab Epicuro ratio neglegendi doloris. Quid de Platone aut de Democrito loquar? Inde igitur, inquit, ordiendum est. Philosophi autem in suis lectulis plerumque moriuntur. Quantum Aristoxeni ingenium consumptum videmus in musicis? Qui enim voluptatem ipsam contemnunt, iis licet dicere se acupenserem maenae non anteponere.

- Sed quia studebat laudi et dignitati, multum in virtute processerat.
- Quae similitudo in genere etiam humano apparet.
- Beatus sibi videtur esse moriens.
- Odium autem et invidiam facile vitabis.
- Commoda autem et incommoda in eo genere sunt, quae praeposita et reiecta diximus;

Quorum altera prosunt, nocent altera. At, si voluptas esset bonum, desideraret. Haec para/doca illi, nos admirabilia dicamus. Et quidem iure fortasse, sed tamen non gravissimum est testimonium multitudinis. Illa argumenta propria videamus, cur omnia sint paria peccata. Hanc ergo intuens debet institutum illud quasi signum absolvere.